Learn R Programming

aoristic (version 1.1.1)

NYburg: Residential burglaries, Manhattan borough, New York City, NY, 2019

Description

A dataset with a residential burglaries in the Borough of Manhattan, New York City, NY for 2019. Data include start and end date-times, and coordinates.

Usage

NYburg

Arguments

Format

A data frame with 1233 rows and 6 variables:

CMPLNT_FR_DT

Crime from date in Date format

CMPLNT_FR_TM

Crime from time in number format

CMPLNT_TO_DT

Crime to date in Date format

CMPLNT_TO_TM

Crime to time in number format

X_COORD_CD

X coordinate of crime event in state plane format

Y_COORD_CD

Y coordinate of crime event in state plane format