aoristic.datacheck: Check aoristic input data

View source: R/aoristic.datacheck.R

aoristic.datacheckR Documentation

Check aoristic input data

Description

Flags missing End/To values with '1' and End/To values before Start/From with '2'. The function also reports missing or zero coordinates.

Usage

aoristic.datacheck(data1, Xcoord, Ycoord, DateTimeFrom, DateTimeTo)

Arguments

data1

Data frame containing coordinates and date-time columns.

Xcoord

Name of the numeric X coordinate or latitude column.

Ycoord

Name of the numeric Y coordinate or longitude column.

DateTimeFrom

Name of the Start/From POSIXct column.

DateTimeTo

Name of the End/To POSIXct column.

Value

A data frame containing the checked fields, elapsed duration, and an 'aoristic_datacheck' flag.

References

Ratcliffe, J. H. (2002). Aoristic signatures and the spatio-temporal analysis of high volume crime patterns. Journal of Quantitative Criminology, 18(1), 23-43.

Examples

datacheck.df <- aoristic.datacheck(
  dcburglaries, "X", "Y", "StartDateTime", "EndDateTime"
)

aoristic documentation built on Sept. 9, 2026, 9:08 a.m.