Summarizes the sum of aoristic weights for each hour of the week, based on output from an aoristic data
frame (created by aoristic.df). The function returns a data frame, with optional outputs.
Option 'xlsx' sends the data frame to an Excel spreadsheet in the current working directory.
Filenames increment to prevent overwriting previous analyses. Using option 'jpg'
creates a color coded summary table in jpg format in the working directory.
The filename is aoristic_distribution.jpg, adding incremental numbers as necessary to the filename.
NOTE: Be aware that the distribution of values is NOT the same as the aoristic.ref() output, because
the summary charts and graphs move Sunday to the end of the week to keep the weekend together.