View source: R/aoristic.datacheck.R
| aoristic.datacheck | R Documentation |
Flags missing End/To values with '1' and End/To values before Start/From with '2'. The function also reports missing or zero coordinates.
aoristic.datacheck(data1, Xcoord, Ycoord, DateTimeFrom, DateTimeTo)
data1 |
Data frame containing coordinates and date-time columns. |
Xcoord |
Name of the numeric X coordinate or latitude column. |
Ycoord |
Name of the numeric Y coordinate or longitude column. |
DateTimeFrom |
Name of the Start/From POSIXct column. |
DateTimeTo |
Name of the End/To POSIXct column. |
A data frame containing the checked fields, elapsed duration, and an 'aoristic_datacheck' flag.
Ratcliffe, J. H. (2002). Aoristic signatures and the spatio-temporal analysis of high volume crime patterns. Journal of Quantitative Criminology, 18(1), 23-43.
datacheck.df <- aoristic.datacheck(
dcburglaries, "X", "Y", "StartDateTime", "EndDateTime"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.